mindroot.coreplugins.mcp\_ package
==================================

Submodules
----------

mindroot.coreplugins.mcp\_.catalog\_commands module
---------------------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.catalog_commands
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.catalog\_manager module
--------------------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.catalog_manager
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.dynamic\_commands module
---------------------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.dynamic_commands
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.mcp\_manager module
----------------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.mcp_manager
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.mod module
-------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.mod
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.oauth\_storage module
------------------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.oauth_storage
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.server\_installer module
---------------------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.server_installer
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.setup module
---------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.setup
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.test\_dynamic\_commands module
---------------------------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.test_dynamic_commands
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.mcp\_.testmcpclient module
-----------------------------------------------

.. automodule:: mindroot.coreplugins.mcp_.testmcpclient
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: mindroot.coreplugins.mcp_
   :members:
   :show-inheritance:
   :undoc-members:
